/// <reference types="react" />
import { LinkOptions } from '../hooks/useLink';
import { ScriptOptions } from '../hooks/useScript';
import { Name, CharSet, HttpEquiv, Property } from '../types';
export declare const META = "M";
export declare const TITLE = "T";
export declare const LINK = "L";
export declare const TEMPLATE = "P";
export declare const SCRIPT = "S";
declare type HeadType = 'T' | 'P' | 'M' | 'L' | 'S';
declare type MetaKeyword = 'name' | 'charset' | 'http-equiv' | 'property';
export interface MetaPayload {
    keyword: MetaKeyword;
    name: Name | string;
    charset: CharSet;
    'http-equiv': HttpEquiv | string;
    property: Property | string;
    content: string;
}
export declare const createDispatcher: () => {
    _setLang: (l: string) => void;
    _addToQueue: (type: HeadType, payload: MetaPayload | string) => void;
    _removeFromQueue: (type: HeadType, payload: MetaPayload | string) => void;
    _change: (type: HeadType, prevPayload: string | MetaPayload, payload: any) => void;
    _reset: (() => void) | undefined;
    toStatic: () => StaticPayload;
};
export declare type StaticPayload = {
    lang?: string;
    title?: string;
    links?: Array<LinkOptions>;
    scripts?: Array<ScriptOptions>;
    metas?: Array<{
        charset: string;
    } | {
        [key: string]: string;
        content: string;
    }>;
};
declare const defaultDispatcher: {
    _setLang: (l: string) => void;
    _addToQueue: (type: HeadType, payload: MetaPayload | string) => void;
    _removeFromQueue: (type: HeadType, payload: MetaPayload | string) => void;
    _change: (type: HeadType, prevPayload: string | MetaPayload, payload: any) => void;
    _reset: (() => void) | undefined;
    toStatic: () => StaticPayload;
};
export default defaultDispatcher;
export declare const DispatcherContext: import("react").Context<{
    _setLang: (l: string) => void;
    _addToQueue: (type: HeadType, payload: MetaPayload | string) => void;
    _removeFromQueue: (type: HeadType, payload: MetaPayload | string) => void;
    _change: (type: HeadType, prevPayload: string | MetaPayload, payload: any) => void;
    _reset: (() => void) | undefined;
    toStatic: () => StaticPayload;
}>;
